@@ -2,7 +2,7 @@
     Compute the data depenency between all the SSA variables
 """
 from collections import defaultdict
-from typing import Union, Set, Dict
+from typing import Union, Set, Dict, TYPE_CHECKING
 
 from slither.core.declarations import (
     Contract,
@@ -26,6 +26,9 @@ from slither.slithir.variables import (
 )
 from slither.core.solidity_types.type import Type
 
+if TYPE_CHECKING:
+    from slither.core.compilation_unit import SlitherCompilationUnit
+
 
 ###################################################################################
 ###################################################################################
@@ -34,7 +37,12 @@ from slither.core.solidity_types.type import Type
 ###################################################################################
 
 
-def is_dependent(variable, source, context, only_unprotected=False):
+def is_dependent(
+    variable: Variable,
+    source: Variable,
+    context: Union[Contract, Function],
+    only_unprotected: bool = False,
+) -> bool:
     """
     Args:
         variable (Variable)
@@ -49,17 +57,22 @@ def is_dependent(variable, source, context, only_unprotected=False):
         return False
     if variable == source:
         return True
-    context = context.context
+    context_dict = context.context
 
     if only_unprotected:
         return (
-            variable in context[KEY_NON_SSA_UNPROTECTED]
-            and source in context[KEY_NON_SSA_UNPROTECTED][variable]
+            variable in context_dict[KEY_NON_SSA_UNPROTECTED]
+            and source in context_dict[KEY_NON_SSA_UNPROTECTED][variable]
         )
-    return variable in context[KEY_NON_SSA] and source in context[KEY_NON_SSA][variable]
+    return variable in context_dict[KEY_NON_SSA] and source in context_dict[KEY_NON_SSA][variable]
 
 
-def is_dependent_ssa(variable, source, context, only_unprotected=False):
+def is_dependent_ssa(
+    variable: Variable,
+    source: Variable,
+    context: Union[Contract, Function],
+    only_unprotected: bool = False,
+) -> bool:
     """
     Args:
         variable (Variable)
@@ -70,17 +83,17 @@ def is_dependent_ssa(variable, source, context, only_unprotected=False):
         bool
     """
     assert isinstance(context, (Contract, Function))
-    context = context.context
+    context_dict = context.context
     if isinstance(variable, Constant):
         return False
     if variable == source:
         return True
     if only_unprotected:
         return (
-            variable in context[KEY_SSA_UNPROTECTED]
-            and source in context[KEY_SSA_UNPROTECTED][variable]
+            variable in context_dict[KEY_SSA_UNPROTECTED]
+            and source in context_dict[KEY_SSA_UNPROTECTED][variable]
         )
-    return variable in context[KEY_SSA] and source in context[KEY_SSA][variable]
+    return variable in context_dict[KEY_SSA] and source in context_dict[KEY_SSA][variable]
 
 
 GENERIC_TAINT = {
@@ -104,8 +117,8 @@ def is_tainted(variable, context, only_unprotected=False, ignore_generic_taint=F
     assert isinstance(only_unprotected, bool)
     if isinstance(variable, Constant):
         return False
-    slither = context.slither
-    taints = slither.context[KEY_INPUT]
+    compilation_unit = context.compilation_unit
+    taints = compilation_unit.context[KEY_INPUT]
     if not ignore_generic_taint:
         taints |= GENERIC_TAINT
     return variable in taints or any(
@@ -126,8 +139,8 @@ def is_tainted_ssa(variable, context, only_unprotected=False, ignore_generic_tai
     assert isinstance(only_unprotected, bool)
     if isinstance(variable, Constant):
         return False
-    slither = context.slither
-    taints = slither.context[KEY_INPUT_SSA]
+    compilation_unit = context.compilation_unit
+    taints = compilation_unit.context[KEY_INPUT_SSA]
     if not ignore_generic_taint:
         taints |= GENERIC_TAINT
     return variable in taints or any(
@@ -258,15 +271,15 @@ def pprint_dependency(context):
 ###################################################################################
 
 
-def compute_dependency(slither):
-    slither.context[KEY_INPUT] = set()
-    slither.context[KEY_INPUT_SSA] = set()
+def compute_dependency(compilation_unit: "SlitherCompilationUnit"):
+    compilation_unit.context[KEY_INPUT] = set()
+    compilation_unit.context[KEY_INPUT_SSA] = set()
 
-    for contract in slither.contracts:
-        compute_dependency_contract(contract, slither)
+    for contract in compilation_unit.contracts:
+        compute_dependency_contract(contract, compilation_unit)
 
 
-def compute_dependency_contract(contract, slither):
+def compute_dependency_contract(contract, compilation_unit: "SlitherCompilationUnit"):
     if KEY_SSA in contract.context:
         return
 
@@ -281,8 +294,8 @@ def compute_dependency_contract(contract, slither):
 
         # pylint: disable=expression-not-assigned
         if function.visibility in ["public", "external"]:
-            [slither.context[KEY_INPUT].add(p) for p in function.parameters]
-            [slither.context[KEY_INPUT_SSA].add(p) for p in function.parameters_ssa]
+            [compilation_unit.context[KEY_INPUT].add(p) for p in function.parameters]
+            [compilation_unit.context[KEY_INPUT_SSA].add(p) for p in function.parameters_ssa]
 
     propagate_contract(contract, KEY_SSA, KEY_NON_SSA)
     propagate_contract(contract, KEY_SSA_UNPROTECTED, KEY_NON_SSA_UNPROTECTED)
