@@ -47,13 +47,14 @@ from slither.core.expressions.expression import Expression
 if TYPE_CHECKING:
     from slither.core.declarations import Function
     from slither.slithir.variables.variable import SlithIRVariable
-    from slither.core.slither_core import SlitherCore
+    from slither.core.compilation_unit import SlitherCompilationUnit
     from slither.utils.type_helpers import (
         InternalCallType,
         HighLevelCallType,
         LibraryCallType,
         LowLevelCallType,
     )
+    from slither.core.cfg.scope import Scope
 
 
 # pylint: disable=too-many-lines,too-many-branches,too-many-instance-attributes
@@ -152,7 +153,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
 
     """
 
-    def __init__(self, node_type: NodeType, node_id: int):
+    def __init__(self, node_type: NodeType, node_id: int, scope: Union["Scope", "Function"]):
         super().__init__()
         self._node_type = node_type
 
@@ -220,6 +221,8 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
 
         self._asm_source_code: Optional[Union[str, Dict]] = None
 
+        self.scope = scope
+
     ###################################################################################
     ###################################################################################
     # region General's properties
@@ -227,8 +230,8 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
     ###################################################################################
 
     @property
-    def slither(self) -> "SlitherCore":
-        return self.function.slither
+    def compilation_unit(self) -> "SlitherCompilationUnit":
+        return self.function.compilation_unit
 
     @property
     def node_id(self) -> int:
