@@ -1,13 +1,12 @@
 from typing import List, TYPE_CHECKING, Dict
 
-from slither.core.children.child_contract import ChildContract
 from slither.core.source_mapping.source_mapping import SourceMapping
 
 if TYPE_CHECKING:
     from slither.core.variables.structure_variable import StructureVariable
 
 
-class Structure(ChildContract, SourceMapping):
+class Structure(SourceMapping):
     def __init__(self):
         super().__init__()
         self._name = None
@@ -39,14 +38,6 @@ class Structure(ChildContract, SourceMapping):
     def add_elem_in_order(self, s: str):
         self._elems_ordered.append(s)
 
-    def is_declared_by(self, contract):
-        """
-        Check if the element is declared by the contract
-        :param contract:
-        :return:
-        """
-        return self.contract == contract
-
     @property
     def elems_ordered(self) -> List["StructureVariable"]:
         ret = []
