@@ -19,6 +19,8 @@ class IncorrectERC20InterfaceDetection(AbstractDetector):
 
     WIKI_TITLE = "Incorrect erc20 interface"
     WIKI_DESCRIPTION = "Incorrect return values for `ERC20` functions. A contract compiled with Solidity > 0.4.22 interacting with these functions will fail to execute them, as the return value is missing."
+
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract Token{
@@ -27,6 +29,7 @@ contract Token{
 }
 ```
 `Token.transfer` does not return a boolean. Bob deploys the token. Alice creates a contract that interacts with it but assumes a correct `ERC20` interface implementation. Alice's contract is unable to interact with Bob's contract."""
+    # endregion wiki_exploit_scenario
 
     WIKI_RECOMMENDATION = (
         "Set the appropriate return values and types for the defined `ERC20` functions."
@@ -97,7 +100,7 @@ contract Token{
             dict: [contract name] = set(str)  events
         """
         results = []
-        for c in self.slither.contracts_derived:
+        for c in self.compilation_unit.contracts_derived:
             functions = IncorrectERC20InterfaceDetection.detect_incorrect_erc20_interface(c)
             if functions:
                 for function in functions:
