@@ -2,19 +2,24 @@
 Module detecting shadowing variables on abstract contract
 Recursively check the called functions
 """
+from typing import List
 
+from slither.core.declarations import Contract
+from slither.core.variables.state_variable import StateVariable
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
+from slither.utils.output import Output, AllSupportedOutput
 
 
-def detect_shadowing(contract):
-    ret = []
+def detect_shadowing(contract: Contract) -> List[List[StateVariable]]:
+    ret: List[List[StateVariable]] = []
     variables_fathers = []
     for father in contract.inheritance:
-        if all(not f.is_implemented for f in father.functions + father.modifiers):
+        if all(not f.is_implemented for f in father.functions + list(father.modifiers)):
             variables_fathers += father.state_variables_declared
 
+    var: StateVariable
     for var in contract.state_variables_declared:
-        shadow = [v for v in variables_fathers if v.name == var.name]
+        shadow: List[StateVariable] = [v for v in variables_fathers if v.name == var.name]
         if shadow:
             ret.append([var] + shadow)
     return ret
@@ -34,6 +39,8 @@ class ShadowingAbstractDetection(AbstractDetector):
 
     WIKI_TITLE = "State variable shadowing from abstract contracts"
     WIKI_DESCRIPTION = "Detection of state variables shadowed from abstract contracts."
+
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract BaseContract{
@@ -45,10 +52,11 @@ contract DerivedContract is BaseContract{
 }
 ```
 `owner` of `BaseContract` is shadowed in `DerivedContract`."""
+    # endregion wiki_exploit_scenario
 
     WIKI_RECOMMENDATION = "Remove the state variable shadowing."
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect shadowing
 
         Recursively visit the calls
@@ -56,14 +64,14 @@ contract DerivedContract is BaseContract{
             list: {'vuln', 'filename,'contract','func', 'shadow'}
 
         """
-        results = []
+        results: List[Output] = []
         for contract in self.contracts:
             shadowing = detect_shadowing(contract)
             if shadowing:
                 for all_variables in shadowing:
                     shadow = all_variables[0]
                     variables = all_variables[1:]
-                    info = [shadow, " shadows:\n"]
+                    info: List[AllSupportedOutput] = [shadow, " shadows:\n"]
                     for var in variables:
                         info += ["\t- ", var, "\n"]
 
