@@ -22,14 +22,16 @@ class CFG(AbstractPrinter):
                 continue
             for function in contract.functions + contract.modifiers:
                 if filename:
-                    filename = "{}-{}-{}.dot".format(filename, contract.name, function.full_name)
+                    new_filename = "{}-{}-{}.dot".format(
+                        filename, contract.name, function.full_name
+                    )
                 else:
-                    filename = "{}-{}.dot".format(contract.name, function.full_name)
-                info += "Export {}\n".format(filename)
+                    new_filename = "{}-{}.dot".format(contract.name, function.full_name)
+                info += "Export {}\n".format(new_filename)
                 content = function.slithir_cfg_to_dot_str()
-                with open(filename, "w", encoding="utf8") as f:
+                with open(new_filename, "w", encoding="utf8") as f:
                     f.write(content)
-                all_files.append((filename, content))
+                all_files.append((new_filename, content))
 
         self.info(info)
 
