@@ -9,25 +9,24 @@ from slither.utils.myprettytable import MyPrettyTable
 
 class Modifiers(AbstractPrinter):
 
-    ARGUMENT = 'modifiers'
-    HELP = 'Print the modifiers called by each function'
+    ARGUMENT = "modifiers"
+    HELP = "Print the modifiers called by each function"
 
-    WIKI = 'https://github.com/trailofbits/slither/wiki/Printer-documentation#modifiers'
+    WIKI = "https://github.com/trailofbits/slither/wiki/Printer-documentation#modifiers"
 
     def output(self, _filename):
         """
-            _filename is not used
-            Args:
-                _filename(string)
+        _filename is not used
+        Args:
+            _filename(string)
         """
 
-        all_txt = ''
+        all_txt = ""
         all_tables = []
 
         for contract in self.slither.contracts_derived:
-            txt = "\nContract %s"%contract.name
-            table = MyPrettyTable(["Function",
-                                   "Modifiers"])
+            txt = "\nContract %s" % contract.name
+            table = MyPrettyTable(["Function", "Modifiers"])
             for function in contract.functions:
                 modifiers = function.modifiers
                 for call in function.all_internal_calls():
@@ -37,11 +36,11 @@ class Modifiers(AbstractPrinter):
                     if isinstance(call, Function):
                         modifiers += call.modifiers
                 table.add_row([function.name, [m.name for m in set(modifiers)]])
-            txt += "\n"+str(table)
+            txt += "\n" + str(table)
             self.info(txt)
 
         res = self.generate_output(all_txt)
         for name, table in all_tables:
             res.add_pretty_table(table, name)
 
-        return res
\ No newline at end of file
+        return res
