@@ -29,7 +29,7 @@ class VariableOrder(AbstractPrinter):
             table = MyPrettyTable(["Name", "Type", "Slot", "Offset"])
             for variable in contract.state_variables_ordered:
                 if not variable.is_constant:
-                    slot, offset = self.slither.storage_layout_of(contract, variable)
+                    slot, offset = contract.compilation_unit.storage_layout_of(contract, variable)
                     table.add_row([variable.canonical_name, str(variable.type), slot, offset])
 
             all_tables.append((contract.name, table))
