@@ -5,11 +5,10 @@ from slither.slithir.utils.utils import is_valid_lvalue
 
 
 class NewElementaryType(Call, OperationWithLValue):
-
     def __init__(self, new_type, lvalue):
         assert isinstance(new_type, ElementaryType)
         assert is_valid_lvalue(lvalue)
-        super(NewElementaryType, self).__init__()
+        super().__init__()
         self._type = new_type
         self._lvalue = lvalue
 
@@ -24,4 +23,4 @@ class NewElementaryType(Call, OperationWithLValue):
     def __str__(self):
         args = [str(a) for a in self.arguments]
 
-        return '{} = new {}({})'.format(self.lvalue, self._type, ','.join(args))
+        return "{} = new {}({})".format(self.lvalue, self._type, ",".join(args))
