@@ -6,30 +6,28 @@ from slither.utils.utils import unroll
 
 
 class AbstractOperation(abc.ABC):
-
     @property
     @abc.abstractmethod
     def read(self):
         """
-            Return the list of variables READ
+        Return the list of variables READ
         """
-        pass
+        pass  # pylint: disable=unnecessary-pass
 
     @property
     @abc.abstractmethod
     def used(self):
         """
-            Return the list of variables used
+        Return the list of variables used
         """
-        pass
+        pass  # pylint: disable=unnecessary-pass
 
 
 class Operation(Context, ChildExpression, ChildNode, AbstractOperation):
-
     @property
     def used(self):
         """
-            By default used is all the variables read
+        By default used is all the variables read
         """
         return self.read
 
