@@ -1,10 +1,11 @@
+from slither.core.declarations import Function
 from slither.slithir.operations.lvalue import OperationWithLValue
 from slither.slithir.utils.utils import is_valid_lvalue, is_valid_rvalue
 
 
 class Push(OperationWithLValue):
-
     def __init__(self, array, value):
+        super().__init__()
         assert is_valid_rvalue(value) or isinstance(value, Function)
         assert is_valid_lvalue(array)
         self._value = value
