@@ -4,12 +4,11 @@ from slither.slithir.variables.tuple import TupleVariable
 
 
 class Unpack(OperationWithLValue):
-
     def __init__(self, result, tuple_var, idx):
         assert is_valid_lvalue(result)
         assert isinstance(tuple_var, TupleVariable)
         assert isinstance(idx, int)
-        super(Unpack, self).__init__()
+        super().__init__()
         self._tuple = tuple_var
         self._idx = idx
         self._lvalue = result
@@ -27,7 +26,6 @@ class Unpack(OperationWithLValue):
         return self._idx
 
     def __str__(self):
-        return "{}({})= UNPACK {} index: {} ".format(self.lvalue,
-                                                     self.lvalue.type,
-                                                     self.tuple,
-                                                     self.index)
+        return "{}({})= UNPACK {} index: {} ".format(
+            self.lvalue, self.lvalue.type, self.tuple, self.index
+        )
