@@ -16,18 +16,18 @@ from slither.solc_parsing.variables.state_variable import StateVariableSolc
 LOGGER = logging.getLogger("ContractSolcParsing")
 
 if TYPE_CHECKING:
-    from slither.solc_parsing.slitherSolc import SlitherSolc
+    from slither.solc_parsing.slither_compilation_unit_solc import SlitherCompilationUnitSolc
     from slither.core.slither_core import SlitherCore
+    from slither.core.compilation_unit import SlitherCompilationUnit
 
 # pylint: disable=too-many-instance-attributes,import-outside-toplevel,too-many-nested-blocks,too-many-public-methods
 
 
 class ContractSolc:
-    def __init__(self, slither_parser: "SlitherSolc", contract: Contract, data):
+    def __init__(self, slither_parser: "SlitherCompilationUnitSolc", contract: Contract, data):
         # assert slitherSolc.solc_version.startswith('0.4')
 
         self._contract = contract
-        self._contract.set_slither(slither_parser.core)
         self._slither_parser = slither_parser
         self._data = data
 
@@ -89,11 +89,11 @@ class ContractSolc:
         return self._linearized_base_contracts
 
     @property
-    def slither(self) -> "SlitherCore":
-        return self._contract.slither
+    def compilation_unit(self) -> "SlitherCompilationUnit":
+        return self._contract.compilation_unit
 
     @property
-    def slither_parser(self) -> "SlitherSolc":
+    def slither_parser(self) -> "SlitherCompilationUnitSolc":
         return self._slither_parser
 
     @property
@@ -254,7 +254,7 @@ class ContractSolc:
 
         st = StructureContract()
         st.set_contract(self._contract)
-        st.set_offset(struct["src"], self._contract.slither)
+        st.set_offset(struct["src"], self._contract.compilation_unit)
 
         st_parser = StructureContractSolc(st, struct, self)
         self._contract.structures_as_dict[st.name] = st
@@ -281,7 +281,7 @@ class ContractSolc:
 
         for varNotParsed in self._variablesNotParsed:
             var = StateVariable()
-            var.set_offset(varNotParsed["src"], self._contract.slither)
+            var.set_offset(varNotParsed["src"], self._contract.compilation_unit)
             var.set_contract(self._contract)
 
             var_parser = StateVariableSolc(var, varNotParsed)
@@ -291,13 +291,13 @@ class ContractSolc:
             self._contract.add_variables_ordered([var])
 
     def _parse_modifier(self, modifier_data: Dict):
-        modif = Modifier(self.slither)
-        modif.set_offset(modifier_data["src"], self._contract.slither)
+        modif = Modifier(self._contract.compilation_unit)
+        modif.set_offset(modifier_data["src"], self._contract.compilation_unit)
         modif.set_contract(self._contract)
         modif.set_contract_declarer(self._contract)
 
         modif_parser = ModifierSolc(modif, modifier_data, self, self.slither_parser)
-        self._contract.slither.add_modifier(modif)
+        self._contract.compilation_unit.add_modifier(modif)
         self._modifiers_no_params.append(modif_parser)
         self._modifiers_parser.append(modif_parser)
 
@@ -309,13 +309,13 @@ class ContractSolc:
         self._modifiersNotParsed = None
 
     def _parse_function(self, function_data: Dict):
-        func = FunctionContract(self.slither)
-        func.set_offset(function_data["src"], self._contract.slither)
+        func = FunctionContract(self._contract.compilation_unit)
+        func.set_offset(function_data["src"], self._contract.compilation_unit)
         func.set_contract(self._contract)
         func.set_contract_declarer(self._contract)
 
         func_parser = FunctionSolc(func, function_data, self, self._slither_parser)
-        self._contract.slither.add_function(func)
+        self._contract.compilation_unit.add_function(func)
         self._functions_no_params.append(func_parser)
         self._functions_parser.append(func_parser)
 
@@ -336,7 +336,7 @@ class ContractSolc:
     ###################################################################################
 
     def log_incorrect_parsing(self, error):
-        if self._contract.slither.disallow_partial:
+        if self._contract.compilation_unit.core.disallow_partial:
             raise ParsingError(error)
         LOGGER.error(error)
         self._contract.is_incorrectly_parsed = True
@@ -404,7 +404,7 @@ class ContractSolc:
         parser: List[FunctionSolc],
         all_elements: Dict[str, Function],
     ):
-        elem = Cls(self.slither)
+        elem = Cls(self._contract.compilation_unit)
         elem.set_contract(self._contract)
         underlying_function = element_parser.underlying_function
         # TopLevel function are not analyzed here
@@ -412,7 +412,7 @@ class ContractSolc:
         elem.set_contract_declarer(underlying_function.contract_declarer)
         elem.set_offset(
             element_parser.function_not_parsed["src"],
-            self._contract.slither,
+            self._contract.compilation_unit,
         )
 
         elem_parser = Cls_parser(
@@ -428,9 +428,9 @@ class ContractSolc:
             explored_reference_id.add(element_parser.referenced_declaration)
         elem_parser.analyze_params()
         if isinstance(elem, Modifier):
-            self._contract.slither.add_modifier(elem)
+            self._contract.compilation_unit.add_modifier(elem)
         else:
-            self._contract.slither.add_function(elem)
+            self._contract.compilation_unit.add_function(elem)
 
         self._slither_parser.add_function_or_modifier_parser(elem_parser)
 
@@ -587,7 +587,7 @@ class ContractSolc:
 
         new_enum = EnumContract(name, canonicalName, values)
         new_enum.set_contract(self._contract)
-        new_enum.set_offset(enum["src"], self._contract.slither)
+        new_enum.set_offset(enum["src"], self._contract.compilation_unit)
         self._contract.enums_as_dict[canonicalName] = new_enum
 
     def _analyze_struct(self, struct: StructureContractSolc):  # pylint: disable=no-self-use
@@ -608,7 +608,7 @@ class ContractSolc:
             for event_to_parse in self._eventsNotParsed:
                 event = Event()
                 event.set_contract(self._contract)
-                event.set_offset(event_to_parse["src"], self._contract.slither)
+                event.set_offset(event_to_parse["src"], self._contract.compilation_unit)
 
                 event_parser = EventSolc(event, event_to_parse, self)
                 event_parser.analyze(self)
