@@ -14,11 +14,13 @@ from slither.core.solidity_types.mapping_type import MappingType
 from slither.core.solidity_types.type import Type
 from slither.core.solidity_types.user_defined_type import UserDefinedType
 from slither.core.variables.function_type_variable import FunctionTypeVariable
+from slither.exceptions import SlitherError
 from slither.solc_parsing.exceptions import ParsingError
 
 if TYPE_CHECKING:
     from slither.core.declarations import Structure, Enum
     from slither.core.declarations.contract import Contract
+    from slither.core.compilation_unit import SlitherCompilationUnit
 
 logger = logging.getLogger("TypeParsing")
 
@@ -196,19 +198,20 @@ def parse_type(t: Union[Dict, UnknownType], caller_context):
     from slither.solc_parsing.variables.function_type_variable import FunctionTypeVariableSolc
     from slither.solc_parsing.declarations.contract import ContractSolc
     from slither.solc_parsing.declarations.function import FunctionSolc
-    from slither.solc_parsing.slitherSolc import SlitherSolc
+    from slither.solc_parsing.slither_compilation_unit_solc import SlitherCompilationUnitSolc
 
+    sl: "SlitherCompilationUnit"
     # Note: for convenicence top level functions use the same parser than function in contract
     # but contract_parser is set to None
-    if isinstance(caller_context, SlitherSolc) or (
+    if isinstance(caller_context, SlitherCompilationUnitSolc) or (
         isinstance(caller_context, FunctionSolc) and caller_context.contract_parser is None
     ):
-        if isinstance(caller_context, SlitherSolc):
-            sl = caller_context.core
+        if isinstance(caller_context, SlitherCompilationUnitSolc):
+            sl = caller_context.compilation_unit
             next_context = caller_context
         else:
             assert isinstance(caller_context, FunctionSolc)
-            sl = caller_context.underlying_function.slither
+            sl = caller_context.underlying_function.compilation_unit
             next_context = caller_context.slither_parser
         structures_direct_access = sl.structures_top_level
         all_structuress = [c.structures for c in sl.contracts]
@@ -232,15 +235,17 @@ def parse_type(t: Union[Dict, UnknownType], caller_context):
             contract = caller_context.underlying_contract
             next_context = caller_context
 
-        structures_direct_access = contract.structures + contract.slither.structures_top_level
-        all_structuress = [c.structures for c in contract.slither.contracts]
+        structures_direct_access = (
+            contract.structures + contract.compilation_unit.structures_top_level
+        )
+        all_structuress = [c.structures for c in contract.compilation_unit.contracts]
         all_structures = [item for sublist in all_structuress for item in sublist]
-        all_structures += contract.slither.structures_top_level
-        enums_direct_access = contract.enums + contract.slither.enums_top_level
-        all_enumss = [c.enums for c in contract.slither.contracts]
+        all_structures += contract.compilation_unit.structures_top_level
+        enums_direct_access = contract.enums + contract.compilation_unit.enums_top_level
+        all_enumss = [c.enums for c in contract.compilation_unit.contracts]
         all_enums = [item for sublist in all_enumss for item in sublist]
-        all_enums += contract.slither.enums_top_level
-        contracts = contract.slither.contracts
+        all_enums += contract.compilation_unit.enums_top_level
+        contracts = contract.compilation_unit.contracts
         functions = contract.functions + contract.modifiers
     else:
         raise ParsingError(f"Incorrect caller context: {type(caller_context)}")
@@ -291,6 +296,21 @@ def parse_type(t: Union[Dict, UnknownType], caller_context):
             all_enums,
         )
 
+    # Introduced with Solidity 0.8
+    if t[key] == "IdentifierPath":
+        if is_compact_ast:
+            return _find_from_type_name(
+                t["name"],
+                functions,
+                contracts,
+                structures_direct_access,
+                all_structures,
+                enums_direct_access,
+                all_enums,
+            )
+
+        raise SlitherError("Solidity 0.8 not supported with the legacy AST")
+
     if t[key] == "ArrayTypeName":
         length = None
         if is_compact_ast:
@@ -337,7 +357,7 @@ def parse_type(t: Union[Dict, UnknownType], caller_context):
         return_values_vars: List[FunctionTypeVariable] = []
         for p in params[index]:
             var = FunctionTypeVariable()
-            var.set_offset(p["src"], caller_context.slither)
+            var.set_offset(p["src"], caller_context.compilation_unit)
 
             var_parser = FunctionTypeVariableSolc(var, p)
             var_parser.analyze(caller_context)
@@ -345,7 +365,7 @@ def parse_type(t: Union[Dict, UnknownType], caller_context):
             params_vars.append(var)
         for p in return_values[index]:
             var = FunctionTypeVariable()
-            var.set_offset(p["src"], caller_context.slither)
+            var.set_offset(p["src"], caller_context.compilation_unit)
 
             var_parser = FunctionTypeVariableSolc(var, p)
             var_parser.analyze(caller_context)
