@@ -69,14 +69,16 @@ def generate_erc20(
     :param type_property: One of ERC20_PROPERTIES.keys()
     :return:
     """
-    if contract.slither.crytic_compile is None:
+    if contract.compilation_unit.core.crytic_compile is None:
         logging.error("Please compile with crytic-compile")
         return
-    if contract.slither.crytic_compile.type not in [
+    if contract.compilation_unit.core.crytic_compile.type not in [
         PlatformType.TRUFFLE,
         PlatformType.SOLC,
     ]:
-        logging.error(f"{contract.slither.crytic_compile.type} not yet supported by slither-prop")
+        logging.error(
+            f"{contract.compilation_unit.core.crytic_compile.type} not yet supported by slither-prop"
+        )
         return
 
     # Check if the contract is an ERC20 contract and if the functions have the correct visibility
@@ -92,7 +94,7 @@ def generate_erc20(
     properties = erc_properties.properties
 
     # Generate the output directory
-    output_dir = _platform_to_output_dir(contract.slither.crytic_compile.platform)
+    output_dir = _platform_to_output_dir(contract.compilation_unit.core.crytic_compile.platform)
     output_dir.mkdir(exist_ok=True)
 
     # Get the properties
@@ -116,13 +118,13 @@ def generate_erc20(
 
     # Generate Echidna config file
     echidna_config_filename = generate_echidna_config(
-        Path(contract.slither.crytic_compile.target).parent, addresses
+        Path(contract.compilation_unit.core.crytic_compile.target).parent, addresses
     )
 
     unit_test_info = ""
 
     # If truffle, generate unit tests
-    if contract.slither.crytic_compile.type == PlatformType.TRUFFLE:
+    if contract.compilation_unit.core.crytic_compile.type == PlatformType.TRUFFLE:
         unit_test_info = generate_truffle_test(contract, type_property, unit_tests, addresses)
 
     logger.info("################################################")
@@ -132,7 +134,7 @@ def generate_erc20(
         logger.info(green(unit_test_info))
 
     logger.info(green("To run Echidna:"))
-    txt = f"\t echidna-test {contract.slither.crytic_compile.target} "
+    txt = f"\t echidna-test {contract.compilation_unit.core.crytic_compile.target} "
     txt += f"--contract {contract_name} --config {echidna_config_filename}"
     logger.info(green(txt))
 
@@ -193,7 +195,7 @@ def _check_compatibility(contract):
 def _get_properties(contract, properties: List[Property]) -> Tuple[str, List[Property]]:
     solidity_properties = ""
 
-    if contract.slither.crytic_compile.type == PlatformType.TRUFFLE:
+    if contract.compilation_unit.crytic_compile.type == PlatformType.TRUFFLE:
         solidity_properties += "\n".join([property_to_solidity(p) for p in ERC20_CONFIG])
 
     solidity_properties += "\n".join([property_to_solidity(p) for p in properties])
