@@ -1,26 +1,30 @@
-from slither.core.solidity_types import (ArrayType, MappingType, ElementaryType)
+from typing import List, Union
+
+from slither.core.solidity_types import ArrayType, MappingType, ElementaryType
+from slither.core.solidity_types.type import Type
+from slither.core.variables.variable import Variable
 
 
-def _add_mapping_parameter(t, l):
+def _add_mapping_parameter(t: Type, l: List[Type]):
     while isinstance(t, MappingType):
         l.append(t.type_from)
         t = t.type_to
     _add_array_parameter(t, l)
 
 
-def _add_array_parameter(t, l):
+def _add_array_parameter(t: Type, l: List[Type]):
     while isinstance(t, ArrayType):
-        l.append(ElementaryType('uint256'))
+        l.append(ElementaryType("uint256"))
         t = t.type
 
 
-def export_nested_types_from_variable(variable):
+def export_nested_types_from_variable(variable: Variable) -> List[Type]:
     """
     Export the list of nested types (mapping/array)
     :param variable:
     :return: list(Type)
     """
-    l = []
+    l: List[Type] = []
     if isinstance(variable.type, MappingType):
         t = variable.type
         _add_mapping_parameter(t, l)
@@ -32,7 +36,7 @@ def export_nested_types_from_variable(variable):
     return l
 
 
-def export_return_type_from_variable(variable):
+def export_return_type_from_variable(variable: Union[Type, Variable]):
     """
     Return the type returned by a variable
     :param variable
@@ -51,5 +55,3 @@ def export_return_type_from_variable(variable):
         return variable.type.type
 
     return variable.type
-
-
